@@ -10,6 +10,7 @@ test_that("x cannot be missing", {
   expect_error(row_t_welch(), er)
   expect_error(row_t_onesample(), er)
   expect_error(row_t_paired(), er)
+  expect_error(row_f_var(), er)
   expect_error(row_oneway_equalvar(), er)
   expect_error(row_oneway_welch(), er)
   expect_error(row_kruskalwallis(), er)
@@ -28,6 +29,7 @@ test_that("y cannot be missing", {
   expect_error(row_t_equalvar(x=NA), er)
   expect_error(row_t_welch(x=NA), er)
   expect_error(row_t_paired(x=NA), er)
+  expect_error(row_f_var(x=NA), er)
   expect_error(row_cor_pearson(x=NA), er)
   expect_error(row_wilcoxon_twosample(x=NA), er)
   expect_error(row_wilcoxon_paired(x=NA), er)
@@ -58,6 +60,7 @@ test_that("x cannot be a character", {
   expect_error(row_t_equalvar(x=matX, y=0), er)
   expect_error(row_t_welch(x=matX, y=0), er)
   expect_error(row_t_paired(x=matX, y=0), er)
+  expect_error(row_f_var(x=matX, y=0), er)
   expect_error(row_oneway_equalvar(x=matX, g="a"), er)
   expect_error(row_oneway_welch(x=matX, g="a"), er)
   expect_error(row_kruskalwallis(x=matX, g="a"), er)
@@ -77,6 +80,7 @@ test_that("y cannot be a character", {
   expect_error(row_t_equalvar(x=0, y=matX), er)
   expect_error(row_t_welch(x=0, y=matX), er)
   expect_error(row_t_paired(x=0, y=matX), er)
+  expect_error(row_f_var(x=0, y=matX), er)
   expect_error(row_cor_pearson(x=0, y=matX), er)
   expect_error(row_wilcoxon_twosample(x=0, y=matX), er)
   expect_error(row_wilcoxon_paired(x=0, y=matX), er)
@@ -89,6 +93,7 @@ test_that("x cannot be partially numeric", {
   expect_error(row_t_equalvar(x=iris, y=0), er)
   expect_error(row_t_welch(x=iris, y=0), er)
   expect_error(row_t_paired(x=iris, y=0), er)
+  expect_error(row_f_var(x=iris, y=0), er)
   expect_error(row_oneway_equalvar(x=iris, g="a"), er)
   expect_error(row_oneway_welch(x=iris, g="a"), er)
   expect_error(row_kruskalwallis(x=iris, g="a"), er)
@@ -107,6 +112,7 @@ test_that("y cannot be partially numeric", {
   expect_error(row_t_equalvar(x=0, y=iris), er)
   expect_error(row_t_welch(x=0, y=iris), er)
   expect_error(row_t_paired(x=0, y=iris), er)
+  expect_error(row_f_var(x=0, y=iris), er)
   expect_error(row_cor_pearson(x=0, y=iris), er)
   expect_error(row_wilcoxon_twosample(x=0, y=iris), er)
   expect_error(row_wilcoxon_paired(x=0, y=iris), er)
@@ -120,6 +126,7 @@ test_that("x cannot be complex", {
   expect_error(row_t_equalvar(x=matX, y=0), er)
   expect_error(row_t_welch(x=matX, y=0), er)
   expect_error(row_t_paired(x=matX, y=0), er)
+  expect_error(row_f_var(x=matX, y=0), er)
   expect_error(row_oneway_equalvar(x=matX, g="a"), er)
   expect_error(row_oneway_welch(x=matX, g="a"), er)
   expect_error(row_kruskalwallis(x=matX, g="a"), er)
@@ -139,6 +146,7 @@ test_that("y cannot be complex", {
   expect_error(row_t_equalvar(x=0, y=matX), er)
   expect_error(row_t_welch(x=0, y=matX), er)
   expect_error(row_t_paired(x=0, y=matX), er)
+  expect_error(row_f_var(x=0, y=matX), er)
   expect_error(row_cor_pearson(x=0, y=matX), er)
   expect_error(row_wilcoxon_twosample(x=0, y=matX), er)
   expect_error(row_wilcoxon_paired(x=0, y=matX), er)
@@ -152,6 +160,7 @@ test_that("x cannot be logical", {
   expect_error(row_t_equalvar(x=matX, y=0), er)
   expect_error(row_t_welch(x=matX, y=0), er)
   expect_error(row_t_paired(x=matX, y=0), er)
+  expect_error(row_f_var(x=matX, y=0), er)
   expect_error(row_oneway_equalvar(x=matX, g="a"), er)
   expect_error(row_oneway_welch(x=matX, g="a"), er)
   expect_error(row_kruskalwallis(x=matX, g="a"), er)
@@ -171,6 +180,7 @@ test_that("y cannot be logical", {
   expect_error(row_t_equalvar(x=0, y=matX), er)
   expect_error(row_t_welch(x=0, y=matX), er)
   expect_error(row_t_paired(x=0, y=matX), er)
+  expect_error(row_f_var(x=0, y=matX), er)
   expect_error(row_cor_pearson(x=0, y=matX), er)
   expect_error(row_wilcoxon_twosample(x=0, y=matX), er)
   expect_error(row_wilcoxon_paired(x=0, y=matX), er)
@@ -183,6 +193,7 @@ test_that("x cannot be NULL", {
   expect_error(row_t_equalvar(x=NULL, y=0), er)
   expect_error(row_t_welch(x=NULL, y=0), er)
   expect_error(row_t_paired(x=NULL, y=0), er)
+  expect_error(row_f_var(x=NULL, y=0), er)
   expect_error(row_oneway_equalvar(x=NULL, g="a"), er)
   expect_error(row_oneway_welch(x=NULL, g="a"), er)
   expect_error(row_kruskalwallis(x=NULL, g="a"), er)
@@ -202,6 +213,7 @@ test_that("y cannot be NULL", {
   expect_error(row_t_equalvar(x=0, y=NULL), er)
   expect_error(row_t_welch(x=0, y=NULL), er)
   expect_error(row_t_paired(x=0, y=NULL), er)
+  expect_error(row_f_var(x=0, y=NULL), er)
   expect_error(row_cor_pearson(x=0, y=NULL), er)
   expect_error(row_wilcoxon_twosample(x=0, y=NULL), er)
   expect_error(row_wilcoxon_paired(x=0, y=NULL), er)
@@ -214,6 +226,7 @@ test_that("x cannot be in a list", {
   expect_error(row_t_equalvar(x=list(1:5), y=0), er)
   expect_error(row_t_welch(x=list(1:5), y=0), er)
   expect_error(row_t_paired(x=list(1:5), y=0), er)
+  expect_error(row_f_var(x=list(1:5), y=0), er)
   expect_error(row_oneway_equalvar(x=list(1:5), g="a"), er)
   expect_error(row_oneway_welch(x=list(1:5), g="a"), er)
   expect_error(row_kruskalwallis(x=list(1:5), g="a"), er)
@@ -233,6 +246,7 @@ test_that("y cannot be in a list", {
   expect_error(row_t_equalvar(x=0, y=list(1:5)), er)
   expect_error(row_t_welch(x=0, y=list(1:5)), er)
   expect_error(row_t_paired(x=0, y=list(1:5)), er)
+  expect_error(row_f_var(x=0, y=list(1:5)), er)
   expect_error(row_cor_pearson(x=0, y=list(1:5)), er)
   expect_error(row_wilcoxon_twosample(x=0, y=list(1:5)), er)
   expect_error(row_wilcoxon_paired(x=0, y=list(1:5)), er)
@@ -244,6 +258,7 @@ test_that("x cannot be a list", {
   expect_error(row_t_equalvar(x=as.list(1:5), y=0), er)
   expect_error(row_t_welch(x=as.list(1:5), y=0), er)
   expect_error(row_t_paired(x=as.list(1:5), y=0), er)
+  expect_error(row_f_var(x=as.list(1:5), y=0), er)
   expect_error(row_oneway_equalvar(x=as.list(1:5), g="a"), er)
   expect_error(row_oneway_welch(x=as.list(1:5), g="a"), er)
   expect_error(row_kruskalwallis(x=as.list(1:5), g="a"), er)
@@ -263,6 +278,7 @@ test_that("y cannot be a list", {
   expect_error(row_t_equalvar(x=0, y=as.list(1:5)), er)
   expect_error(row_t_welch(x=0, y=as.list(1:5)), er)
   expect_error(row_t_paired(x=0, y=as.list(1:5)), er)
+  expect_error(row_f_var(x=0, y=as.list(1:5)), er)
   expect_error(row_cor_pearson(x=0, y=as.list(1:5)), er)
   expect_error(row_wilcoxon_twosample(x=0, y=as.list(1:5)), er)
   expect_error(row_wilcoxon_paired(x=0, y=as.list(1:5)), er)
@@ -344,6 +360,7 @@ test_that("x and y has same number of rows", {
   expect_error(row_t_equalvar(x=matX, y=matY), er)
   expect_error(row_t_welch(x=matX, y=matY), er)
   expect_error(row_t_paired(x=matX, y=matY), er)
+  expect_error(row_f_var(x=matX, y=matY), er)
   expect_error(row_cor_pearson(x=matX, y=matY), er)
   expect_error(row_wilcoxon_twosample(x=matX, y=matY), er)
   expect_error(row_wilcoxon_paired(x=matX, y=matY), er)
