@@ -12,6 +12,7 @@ test_that("x and y can be numeric vectors", {
   expect_equal(row_t_equalvar(x=x, y=y), row_t_equalvar(x=X, y=Y))
   expect_equal(row_t_welch(x=x, y=y), row_t_welch(x=X, y=Y))
   expect_equal(row_t_paired(x=x, y=y), row_t_paired(x=X, y=Y))
+  expect_equal(row_f_var(x=x, y=y), row_f_var(x=X, y=Y))
   expect_equal(row_cor_pearson(x=x, y=y), row_cor_pearson(x=X, y=Y))
   expect_equal(row_oneway_equalvar(x=x, g=grp), row_oneway_equalvar(x=X, g=grp))
   expect_equal(row_oneway_welch(x=x, g=grp), row_oneway_welch(x=X, g=grp))
@@ -33,6 +34,7 @@ test_that("x and y can be numeric data.frames", {
   expect_equal(row_t_equalvar(x=x, y=y), row_t_equalvar(x=X, y=Y))
   expect_equal(row_t_welch(x=x, y=y), row_t_welch(x=X, y=Y))
   expect_equal(row_t_paired(x=x, y=y), row_t_paired(x=X, y=Y))
+  expect_equal(row_f_var(x=x, y=y), row_f_var(x=X, y=Y))
   expect_equal(row_cor_pearson(x=x, y=y), row_cor_pearson(x=X, y=Y))
   expect_equal(row_oneway_equalvar(x=x, g=grp), row_oneway_equalvar(x=X, g=grp))
   expect_equal(row_oneway_welch(x=x, g=grp), row_oneway_welch(x=X, g=grp))
@@ -54,6 +56,7 @@ test_that("x and y can have 0 rows and 0 columns", {
   expect_equal(nrow(row_t_equalvar(x=x, y=y)), 0)
   expect_equal(nrow(row_t_welch(x=x, y=y)), 0)
   expect_equal(nrow(row_t_paired(x=x, y=y)), 0)
+  expect_equal(nrow(row_f_var(x=x, y=y)), 0)
   expect_equal(nrow(row_cor_pearson(x=x, y=y)), 0)
   expect_equal(nrow(row_oneway_equalvar(x=x, g=grp)), 0)
   expect_equal(nrow(row_oneway_welch(x=x, g=grp)), 0)
@@ -80,6 +83,7 @@ test_that("NA and NaN are treated the same", {
   expect_equal(row_t_equalvar(x=Xna, y=Yna), row_t_equalvar(x=Xnan, y=Ynan))
   expect_equal(row_t_welch(x=Xna, y=Yna), row_t_welch(x=Xnan, y=Ynan))
   expect_equal(row_t_paired(x=Xna, y=Yna), row_t_paired(x=Xnan, y=Ynan))
+  expect_equal(row_f_var(x=Xna, y=Yna), row_f_var(x=Xnan, y=Ynan))
   expect_equal(row_cor_pearson(x=Xna, y=Yna), row_cor_pearson(x=Xnan, y=Ynan))
   expect_equal(row_oneway_equalvar(x=Xna, g=grp), row_oneway_equalvar(x=Xnan, g=grp))
   expect_equal(row_oneway_welch(x=Xna, g=grp), row_oneway_welch(x=Xnan, g=grp))
@@ -103,6 +107,7 @@ test_that("x is a matrix and y is a vector", {
   expect_equal(row_t_equalvar(x=X, y=y), row_t_equalvar(x=X, y=Y))
   expect_equal(row_t_welch(x=X, y=y), row_t_welch(x=X, y=Y))
   expect_equal(row_t_paired(x=X, y=y), row_t_paired(x=X, y=Y))
+  expect_equal(row_f_var(x=X, y=y), row_f_var(x=X, y=Y))
   expect_equal(row_cor_pearson(x=X, y=y), row_cor_pearson(x=X, y=Y))
   expect_equal(row_wilcoxon_twosample(x=X, y=y), row_wilcoxon_twosample(x=X, y=Y))
   expect_equal(row_wilcoxon_paired(x=X, y=y), row_wilcoxon_paired(x=X, y=Y))
@@ -168,7 +173,6 @@ test_that("all observations can be in the same group", {
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
 })
 
-
 test_that("groups can be character", {
   x <- t(iris[,-5])
   grp1 <- sample(c("A", "B"), ncol(x), replace=TRUE)
@@ -267,6 +271,7 @@ test_that("alternative can be partially completed", {
   expect_equal(row_t_equalvar(x=x, y=y, alternative=alt1), row_t_equalvar(x=x, y=y, alternative=alt2))
   expect_equal(row_t_welch(x=x, y=y, alternative=alt1), row_t_welch(x=x, y=y, alternative=alt2))
   expect_equal(row_t_paired(x=x, y=y, alternative=alt1), row_t_paired(x=x, y=y, alternative=alt2))
+  expect_equal(row_f_var(x=x, y=y, alternative=alt1), row_f_var(x=x, y=y, alternative=alt2))
   expect_equal(row_cor_pearson(x=x, y=y, alternative=alt1), row_cor_pearson(x=x, y=y, alternative=alt2))
   expect_equal(row_wilcoxon_onesample(x=x, alternative=alt1), row_wilcoxon_onesample(x=x, alternative=alt2))
   expect_equal(row_wilcoxon_twosample(x=x, y=y, alternative=alt1), row_wilcoxon_twosample(x=x, y=y, alternative=alt2))
